@@ -1,4 +1,4 @@
-# Copyright 2022-2024 MetaOPT Team. All Rights Reserved.
+# Copyright 2022-2025 MetaOPT Team. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +14,8 @@
 # ==============================================================================
 """OpTree: Optimized PyTree Utilities."""
 
-from optree import accessor, functools, integration, typing
-from optree.accessor import (
+from optree import accessors, dataclasses, functools, integrations, pytree, treespec, typing
+from optree.accessors import (
     AutoEntry,
     DataclassEntry,
     FlattenedEntry,
@@ -28,7 +28,6 @@ from optree.accessor import (
     SequenceEntry,
     StructSequenceEntry,
 )
-from optree.functools import Partial
 from optree.ops import (
     MAX_RECURSION_DEPTH,
     NONE_IS_LEAF,
@@ -60,6 +59,7 @@ from optree.ops import (
     tree_map_with_path_,
     tree_max,
     tree_min,
+    tree_partition,
     tree_paths,
     tree_reduce,
     tree_replace_nones,
@@ -80,6 +80,7 @@ from optree.ops import (
     treespec_entry,
     treespec_from_collection,
     treespec_is_leaf,
+    treespec_is_one_level,
     treespec_is_prefix,
     treespec_is_strict_leaf,
     treespec_is_suffix,
@@ -87,16 +88,15 @@ from optree.ops import (
     treespec_list,
     treespec_namedtuple,
     treespec_none,
+    treespec_one_level,
     treespec_ordereddict,
     treespec_paths,
     treespec_structseq,
+    treespec_transform,
     treespec_tuple,
 )
 from optree.registry import (
-    AttributeKeyPathEntry,
-    GetitemKeyPathEntry,
     dict_insertion_ordered,
-    register_keypaths,
     register_pytree_node,
     register_pytree_node_class,
     unregister_pytree_node,
@@ -119,7 +119,7 @@ from optree.typing import (
     namedtuple_fields,
     structseq_fields,
 )
-from optree.version import __version__
+from optree.version import __version__ as __version__  # pylint: disable=useless-import-alias
 
 
 __all__ = [
@@ -145,6 +145,7 @@ __all__ = [
     'tree_map_with_accessor',
     'tree_map_with_accessor_',
     'tree_replace_nones',
+    'tree_partition',
     'tree_transpose',
     'tree_transpose_map',
     'tree_transpose_map_with_path',
@@ -170,8 +171,11 @@ __all__ = [
     'treespec_entry',
     'treespec_children',
     'treespec_child',
+    'treespec_one_level',
+    'treespec_transform',
     'treespec_is_leaf',
     'treespec_is_strict_leaf',
+    'treespec_is_one_level',
     'treespec_is_prefix',
     'treespec_is_suffix',
     'treespec_leaf',
@@ -216,13 +220,13 @@ __all__ = [
     'is_namedtuple_instance',
     'namedtuple_fields',
     'is_structseq',
-    'is_structseq_instance',
     'is_structseq_class',
+    'is_structseq_instance',
     'structseq_fields',
 ]
 
-MAX_RECURSION_DEPTH: int = MAX_RECURSION_DEPTH  # 1000
-"""Maximum recursion depth for pytree traversal. It is 1000.
+MAX_RECURSION_DEPTH: int = MAX_RECURSION_DEPTH
+"""Maximum recursion depth for pytree traversal.
 
 This limit prevents infinite recursion from causing an overflow of the C stack
 and crashing Python.
@@ -231,3 +235,22 @@ NONE_IS_NODE: bool = NONE_IS_NODE  # literal constant
 """Literal constant that treats :data:`None` as a pytree non-leaf node."""
 NONE_IS_LEAF: bool = NONE_IS_LEAF  # literal constant
 """Literal constant that treats :data:`None` as a pytree leaf node."""
+
+
+# pylint: disable-next=fixme
+# TODO: remove this function in version 0.18.0
+def __getattr__(name: str, /) -> object:  # pragma: no cover
+    """Get an attribute from the module."""
+    if name == 'accessor':
+        global accessor  # pylint: disable=global-statement
+
+        import optree.accessor as accessor  # pylint: disable=import-outside-toplevel
+
+        return accessor  # type: ignore[name-defined]
+    if name == 'integration':
+        global integration  # pylint: disable=global-statement
+
+        import optree.integration as integration  # pylint: disable=import-outside-toplevel
+
+        return integration  # type: ignore[name-defined]
+    raise AttributeError(f'module {__name__!r} has no attribute {name!r}')
